-- set our default settings
BugCatcher_Options = {
	posX = 200,
	posY = 100,
	height = 400,
	width = 300,
	fontSize = 12,
}

-- make the options local so no other addon can mess with them
local db = {}
for k,v in pairs(BugCatcher_Options) do
	db[k] = v
end

local context = context or UI.CreateContext("Context")	
local bugFrame = bugFrame or UI.CreateFrame("Frame", "BugFrame", context)
bugFrame.text = bugFrame.text or UI.CreateFrame("Text", "ErrorText", bugFrame)

local function BugFrame(bug)
	if not bug then return end
	
	bugFrame:SetLayer(-1) -- set it behind the text
	bugFrame:SetBackgroundColor(0, 0, 0, 0.5) -- black with half alpha
	bugFrame:SetWidth(db.height)
	bugFrame:SetHeight(db.width)
	bugFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", db.posX, db.posY)
	
	bugFrame.text:SetText(bug)
	bugFrame.text:SetPoint("TOPLEFT", bugFrame, "TOPLEFT")
	bugFrame.text:SetPoint("BOTTOMRIGHT", bugFrame, "BOTTOMRIGHT")
	bugFrame.text:SetFontSize(db.fontSize)
	-- bugFrame.text:SetHeight(bugFrame:GetHeight())
	-- bugFrame.text.SetWidth(bugFrame:GetWidth())
	bugFrame.text:SetWordWrap(true)
	
	bugFrame:SetVisible(true)
	
	-- when the frame is clicked, empty the error text and hide the frame
	function bugFrame.Event:LeftUp()
		bugFrame.text = ""
		bugFrame:SetVisible(false)
	end
end

local function Config(args)
	local cmd = args:match("(%a+)")
	cmd = tostring(cmd)
	
	if cmd == "width" then
		if not x then
			print("Example: /bugcatcher width 400")
		end
		db.width = x
		bugFrame:SetHeight(db.width)
		
	elseif cmd == "pos" then
		if x and y then
			db.posX = x
			db.posY = y
			bugFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", db.posX, db.posY)
		else
			print("Example: /bugcatcher pos 200 100")
		end
		
	elseif cmd == "height" then
		if not x then
			print("Example: /bugcatcher height 300")
		end
		db.height = x
		bugFrame:SetWidth(db.height)
		
	elseif cmd == "fontsize" then
		if not x then
			print("Example: /bugcatcher fontsize 12")
		end
		db.fontSize = x
		bugFrame.text:SetFontSize(db.fontSize)
		
	elseif cmd == "test" then
		if x then
			print("Example: /bugcatcher test")
		end
		print("This will test if the string \""A"\" is the same as the string \""B\"")
		error("A" == "B")
		
	else
		print("Example: /bugcatcher width 400")
		print("Example: /bugcatcher pos 200 100")
		print("Example: /bugcatcher height 300")
		print("Example: /bugcatcher fontsize 12")
		print("Example: /bugcatcher test")
	end
end

local function SaveOptions(addon)
	for k,v in pairs(db) do
		BugCatcher_Options[k] = db[k]
	end
end

table.insert(Event.System.Error, {BugFrame, "BugCatcher", "Error Frame"})
table.insert(Event.Addon.SavedVariables.Save.Begin, {SaveOptions, "BugCatcher", "Save Options"})
table.insert(Command.Slash.Register("bugcatcher"), {Config, "BugCatcher", "Process Commands"})